@@ -121,7 +121,11 @@ class AgentRunner(ABC):
         self._tools = all_tools
 
     @staticmethod
-    def from_yaml(yaml_path: str) -> "AgentRunner":
+    def from_yaml(
+        yaml_path: str, 
+        agent_id_override: Optional[str] = None,
+        connection_override: Optional[Dict[str, Any]] = None
+    ) -> "AgentRunner":
         """Create an agent runner from a YAML file.
 
         This method loads a WorkerAgent (which is a type of AgentRunner) from a YAML
@@ -129,6 +133,8 @@ class AgentRunner(ABC):
 
         Args:
             yaml_path: The path to the YAML configuration file
+            agent_id_override: Optional agent ID to override the one in config
+            connection_override: Optional connection settings to override config
 
         Returns:
             AgentRunner: A configured WorkerAgent instance (subclass of AgentRunner)
@@ -145,7 +151,7 @@ class AgentRunner(ABC):
         from openagents.utils.agent_loader import load_agent_from_yaml
 
         # Load the agent using our utility function (ignore connection settings here)
-        agent, _ = load_agent_from_yaml(yaml_path)
+        agent, _ = load_agent_from_yaml(yaml_path, agent_id_override, connection_override)
         return agent
 
     @property
@@ -337,14 +343,11 @@ class AgentRunner(ABC):
                 unprocessed_count = 0
 
                 for thread_id, thread in event_threads.items():
-                    print(f"   Thread {thread_id}: {len(thread.events)} messages")
+                    # Only log thread summary once when messages change, not on every poll
                     for message in thread.events:
                         total_messages += 1
                         # Check if message hasn't been processed (regardless of requires_response)
                         message_id = str(message.message_id)
-                        print(
-                            f"     Message {message_id[:8]}... from {message.source_id}, processed={message_id in self._processed_message_ids}"
-                        )
                         if message_id not in self._processed_message_ids:
                             unprocessed_count += 1
                             # Find the earliest unprocessed message by timestamp
@@ -357,12 +360,16 @@ class AgentRunner(ABC):
 
                 # If we found an unprocessed message, process it
                 if unprocessed_message and unprocessed_thread_id:
-                    print(
-                        f"🔧 AGENT_RUNNER: Found unprocessed message {unprocessed_message.message_id[:8]}... from {unprocessed_message.source_id}"
-                    )
-                    print(
-                        f"🎯 Processing message {unprocessed_message.message_id[:8]}... from {unprocessed_message.source_id}"
-                    )
+                    # Get message content for better logging
+                    msg_content_preview = "No content"
+                    if hasattr(unprocessed_message, 'text') and unprocessed_message.text:
+                        msg_content_preview = f'"{unprocessed_message.text[:50]}{"..." if len(unprocessed_message.text) > 50 else ""}"'
+                    
+                    print(f"🔧 AGENT_RUNNER: Found unprocessed message {unprocessed_message.message_id[:8]}... from {unprocessed_message.source_id}")
+                    print(f"🎯 PROCESSING MESSAGE: {unprocessed_message.message_id[:8]}...")
+                    print(f"   From: {unprocessed_message.source_id}")
+                    print(f"   Content: {msg_content_preview}")
+                    print(f"   Timestamp: {unprocessed_message.timestamp}")
                     # logger.info(f"🔧 AGENT_RUNNER: Found unprocessed message {unprocessed_message.message_id[:8]}... from {unprocessed_message.source_id}")
                     # print(f"🎯 Processing message {unprocessed_message.message_id[:8]}... from {unprocessed_message.source_id}")
                     # Mark the message as processed to avoid processing it again
@@ -393,13 +400,18 @@ class AgentRunner(ABC):
                         event_threads=filtered_threads,
                         incoming_thread_id=unprocessed_thread_id,
                     )
-                    print(
-                        f"🔧 AGENT_RUNNER: Calling react method for message {unprocessed_message.message_id[:8]}..."
-                    )
+                    print(f"🔧 AGENT_RUNNER: Calling react method for message {unprocessed_message.message_id[:8]}...")
+                    
+                    import time
+                    start_time = time.time()
                     await self.react(context)
-                    print(
-                        f"🔧 AGENT_RUNNER: react method completed for message {unprocessed_message.message_id[:8]}"
-                    )
+                    elapsed = time.time() - start_time
+                    
+                    print(f"✅ AGENT RESPONSE COMPLETED: {unprocessed_message.message_id[:8]}")
+                    print(f"   Processing time: {elapsed:.2f}s")
+                    if elapsed > 1.0:
+                        print(f"   🤖 LLM API call detected (response time > 1s)")
+                    print(f"   Message marked as processed")
                 else:
                     await asyncio.sleep(self._interval or 1)
                     # print("😴 No unprocessed messages found, sleeping...")
@@ -727,4 +739,5 @@ class AgentRunner(ABC):
 
     def send_human_message(self, message: str):
         # TODO: Implement this
+        _ = message  # Silence unused variable warning
         pass
