@@ -819,3 +819,183 @@ class ReactionMessage:
     def get_request_id(event: Event) -> Optional[str]:
         """Extract request_id from event payload."""
         return event.payload.get("request_id") if event.payload else None
+
+@dataclass
+class AnnouncementSetMessage(Event):
+    """Message for setting a channel announcement."""
+    
+    channel: str = field(default="")
+    text: str = field(default="")
+    
+    def __init__(self, event_name: str = "thread.announcement.set", source_id: str = "", **kwargs):
+        """Initialize AnnouncementSetMessage with proper event name."""
+        # Map old field names to modern API
+        if 'sender_id' in kwargs:
+            source_id = kwargs.pop('sender_id')
+        if 'content' in kwargs:
+            kwargs['payload'] = kwargs.pop('content')
+        
+        # Remove mod field if present (not needed by Event)
+        kwargs.pop('mod', None)
+        
+        # Extract announcement specific fields
+        channel = kwargs.pop('channel', '')
+        text = kwargs.pop('text', '')
+        
+        # Call parent constructor
+        super().__init__(event_name=event_name, source_id=source_id, **kwargs)
+        
+        # Set announcement specific fields
+        self.channel = channel
+        self.text = text
+    
+    # Backward compatibility properties
+    @property
+    def message_id(self) -> str:
+        """Backward compatibility: message_id maps to event_id."""
+        return self.event_id
+    
+    @message_id.setter
+    def message_id(self, value: str):
+        """Backward compatibility: message_id maps to event_id."""
+        self.event_id = value
+    
+    @property
+    def sender_id(self) -> str:
+        """Backward compatibility: sender_id maps to source_id."""
+        return self.source_id
+    
+    @sender_id.setter
+    def sender_id(self, value: str):
+        """Backward compatibility: sender_id maps to source_id."""
+        self.source_id = value
+    
+    @property
+    def content(self) -> Dict[str, Any]:
+        """Backward compatibility: content maps to payload."""
+        return self.payload
+    
+    @content.setter
+    def content(self, value: Dict[str, Any]):
+        """Backward compatibility: content maps to payload."""
+        self.payload = value
+    
+    @property
+    def message_type(self) -> str:
+        """Backward compatibility: message_type derived from class name."""
+        return "announcement_set"
+    
+    def model_dump(self) -> Dict[str, Any]:
+        """Pydantic-style model dump for backward compatibility."""
+        return {
+            "event_id": self.event_id,
+            "event_name": self.event_name,
+            "timestamp": self.timestamp,
+            "source_id": self.source_id,
+            "source_type": self.source_type,
+            "target_agent_id": self.destination_id,
+            "relevant_mod": self.relevant_mod,
+            "requires_response": self.requires_response,
+            "response_to": self.response_to,
+            "payload": self.payload,
+            "metadata": self.metadata,
+            "text_representation": self.text_representation,
+            "visibility": self.visibility.value if hasattr(self.visibility, 'value') else self.visibility,
+            "allowed_agents": list(self.allowed_agents) if self.allowed_agents else None,
+            # Announcement specific fields
+            "channel": self.channel,
+            "text": self.text,
+            # Backward compatibility fields
+            "message_id": self.event_id,
+            "sender_id": self.source_id,
+            "message_type": self.message_type,
+            "content": self.payload
+        }
+
+@dataclass
+class AnnouncementGetMessage(Event):
+    """Message for getting a channel announcement."""
+    
+    channel: str = field(default="")
+    
+    def __init__(self, event_name: str = "thread.announcement.get", source_id: str = "", **kwargs):
+        """Initialize AnnouncementGetMessage with proper event name."""
+        # Map old field names to modern API
+        if 'sender_id' in kwargs:
+            source_id = kwargs.pop('sender_id')
+        if 'content' in kwargs:
+            kwargs['payload'] = kwargs.pop('content')
+        
+        # Remove mod field if present (not needed by Event)
+        kwargs.pop('mod', None)
+        
+        # Extract announcement specific fields
+        channel = kwargs.pop('channel', '')
+        
+        # Call parent constructor
+        super().__init__(event_name=event_name, source_id=source_id, **kwargs)
+        
+        # Set announcement specific fields
+        self.channel = channel
+    
+    # Backward compatibility properties
+    @property
+    def message_id(self) -> str:
+        """Backward compatibility: message_id maps to event_id."""
+        return self.event_id
+    
+    @message_id.setter
+    def message_id(self, value: str):
+        """Backward compatibility: message_id maps to event_id."""
+        self.event_id = value
+    
+    @property
+    def sender_id(self) -> str:
+        """Backward compatibility: sender_id maps to source_id."""
+        return self.source_id
+    
+    @sender_id.setter
+    def sender_id(self, value: str):
+        """Backward compatibility: sender_id maps to source_id."""
+        self.source_id = value
+    
+    @property
+    def content(self) -> Dict[str, Any]:
+        """Backward compatibility: content maps to payload."""
+        return self.payload
+    
+    @content.setter
+    def content(self, value: Dict[str, Any]):
+        """Backward compatibility: content maps to payload."""
+        self.payload = value
+    
+    @property
+    def message_type(self) -> str:
+        """Backward compatibility: message_type derived from class name."""
+        return "announcement_get"
+    
+    def model_dump(self) -> Dict[str, Any]:
+        """Pydantic-style model dump for backward compatibility."""
+        return {
+            "event_id": self.event_id,
+            "event_name": self.event_name,
+            "timestamp": self.timestamp,
+            "source_id": self.source_id,
+            "source_type": self.source_type,
+            "target_agent_id": self.destination_id,
+            "relevant_mod": self.relevant_mod,
+            "requires_response": self.requires_response,
+            "response_to": self.response_to,
+            "payload": self.payload,
+            "metadata": self.metadata,
+            "text_representation": self.text_representation,
+            "visibility": self.visibility.value if hasattr(self.visibility, 'value') else self.visibility,
+            "allowed_agents": list(self.allowed_agents) if self.allowed_agents else None,
+            # Announcement specific fields
+            "channel": self.channel,
+            # Backward compatibility fields
+            "message_id": self.event_id,
+            "sender_id": self.source_id,
+            "message_type": self.message_type,
+            "content": self.payload
+        }
\ No newline at end of file
